package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.42.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.42.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````>!X```````!``````````)BA````
M````!0```$``.``*`$``%@`5``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```"4`@``````
M`)0"````````E`(````````:`````````!H``````````0`````````#``!P
M!````&R@`````````````````````````````&8````````````````````!
M``````````$````%````````````````````````````````````9)0`````
M``!DE``````````0`````````0````8```"XFP```````+BK````````N*L`
M``````"8!````````/`$`````````!`````````"````!@```,B;````````
MR*L```````#(JP```````.`!````````X`$````````(``````````0````$
M````<`(```````!P`@```````'`"````````)``````````D``````````0`
M````````4.5T9`0```"0C0```````)"-````````D(T```````#4````````
M`-0`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````N)L```````"X
MJP```````+BK````````2`0```````!(!`````````$`````````!````!0`
M```#````1TY5`*PR/2;AFAX.ZUCJ54`2%\:88(=V+VQI8B]L9"UM=7-L+7)I
M<V-V-C0N<V\N,0```!$```!,````!`````@````@D!``!4`$@"@`$02`A@2$
M@H$``@D`!`B(@!!!N@`"B`````!,````3P```%(```!3````6@```%L```!<
M````7@```%\```!@````8@```&,```!D````9@``````````````SMY'+6[%
MWQ]K?YI\+L6;MB#_Y`[59-1\V7%8'+(!BV^83\.;PN4_+$+ZUX?ZH6Q@NN.2
M?.-'Q@%5PSS29Z_,9H@'<--#1=7L<U"?V#-BV^T^S])L%8PES/]A\F%_J9R;
MX*<""FL:GE"CX/M)``````````````````````````````````````,`"0#P
M'```````````````````D`(``!(`````````````````````````NP$``!(`
M````````````````````````8````!(`````````````````````````W`(`
M`!(`````````````````````````P0```!$`````````````````````````
MCP$``!(`````````````````````````1````!(`````````````````````
M````.0$``!(`````````````````````````^`$``!(`````````````````
M````````N````!(`````````````````````````TP```"(`````````````
M````````````6`$``!(`````````````````````````W0$``!(`````````
M````````````````?@(``!(`````````````````````````H`$``!(`````
M````````````````````'`$``!(`````````````````````````EP(``!(`
M````````````````````````YP(``"$`````````````````````````/@``
M`!(`````````````````````````Y@(``!$`````````````````````````
MT`$``!$`````````````````````````1P$``!(`````````````````````
M````2@0``"(`````````````````````````9P(``!(`````````````````
M````````<````!(`````````````````````````%P(``!(`````````````
M````````````Z`(``!$`````````````````````````J0```!(`````````
M````````````````/@(``!(`````````````````````````)@```"``````
M````````````````````;0$``!(`````````````````````````_0```"``
M````````````````````````Y0(``"$`````````````````````````>```
M`!(`````````````````````````%P$``!(`````````````````````````
M:````!(`````````````````````````60```!(`````````````````````
M````%P```!(`````````````````````````-0(``!(`````````````````
M````````K@(``!(`````````````````````````"0```!(`````````````
M````````````KP$``!(`````````````````````````AP```"``````````
M````````````````IP(``!(`````````````````````````5P(``!(`````
M````````````````````4@```!(`````````````````````````!`(``!(`
M`````````````````````````0```!(`````````````````````````2P``
M`!(`````````````````````````/@0``!(`````````````````````````
MQ`(``"(`````````````````````````20(``!(`````````````````````
M````GP(``!(`````````````````````````$````!$`````````````````
M````````)0(``!(`````````````````````````>0```!(`````````````
M````````````A0(``!(`````````````````````````'P```!(`````````
M````````````````(@$``!(`````````````````````````^````!(`````
M````````````````````?`$``!8`````````````````````````M0(``!(`
M````````````````````````R@(``!(`````````````````````````0`$`
M`!(`````````````````````````HP```!(`````````````````````````
ML0```!(`````````````````````````?@```!(`````````````````````
M````7P$``!(`````````````````````````<@(``!(`````````````````
M````````,P$``!(`````````````````````````X@```"``````````````
M````````````[@$``!(`````````````````````````J````!(`````````
M````````````````\P$``!(`````````````````````````JP,``!(`"0`^
M+0```````*H$````````N`,``!(`"0"P,P```````*0`````````UP(``!(`
M"0#P'````````(@!````````+P,``!(`"0"@)`````````(`````````9`,`
M`!(`"0"B)````````+8!````````>0,``!(`"0#H,0```````,@!````````
MT`,``!``$@!0L```````````````````2@,``!(`"0#>*@```````$X`````
M````<0,``!(`"0`L*P```````$8`````````CP,``!(`"0"4(P```````"@`
M````````H`,``!(`"0!*20```````#(!````````W`,``!(`"0""+```````
M`+P`````````&@0``!``$@"HL```````````````````'P0``!(`"0!8)@``
M`````"(`````````EP,``!(`"0"0'@```````"(`````````6`,``!(`"0!Z
M)@```````.0`````````0`,``!$`$0!(L`````````@`````````$P0``!``
M$0!0L```````````````````'P,``!``$0!0L```````````````````U0,`
M`!(`"0!X'@``````````````````!`0``!``$0``L```````````````````
M1P0``!(`"0#T2````````%8`````````Q`,``!``$@"HL```````````````
M````+`0``!(`"0!L+````````!8`````````[@,``!(`"0"\(P```````.0`
M````````4`0``!(`"0!\2@```````+0!````````$@,``!(`"0!>)P``````
M`(`#`````````&]P96YD:7(`;65M8VUP`'-T9&5R<@!R96%L;&]C`&%C8V5S
M<P!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E:P!G971P:60`<W1R8VUP
M`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S=')N8VUP`'-T<G)C:'(`;'-T870`
M8VQO<V5D:7(`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`&]P96X`=F9P
M<FEN=&8`<W1R8VAR`')E861L:6YK`%]?<W1A8VM?8VAK7V=U87)D`%]?8WAA
M7V9I;F%L:7IE`%]?<F5G:7-T97)?9G)A;65?:6YF;P!E>&ET`%])5$U?<F5G
M:7-T97)434-L;VYE5&%B;&4`<F5A9`!R;61I<@!?7V5R<FYO7VQO8V%T:6]N
M`&UK9&ER`&UE;6-P>0!S=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`
M4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!03%]C=7)R96YT7V-O;G1E
M>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S
M=@!097)L7V-R;V%K7VYO8V]N=&5X=`!03%]D;U]U;F1U;7``4&5R;%]N97=8
M4U]F;&%G<P!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL
M;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E
M<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P
M87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!S=')C<'D`<F5A
M9&1I<@!S<')I;G1F`'-T<F1U<`!S=')T;VL`<'1H<F5A9%]A=&9O<FL`7V9I
M;FD`7U]L:6)C7W-T87)T7VUA:6X`<VYP<FEN=&8`7U]?96YV:7)O;@!L:6)P
M97)L+G-O`&QI8F,N;75S;"UR:7-C=C8T+G-O+C$`<&%R7VEN:71?96YV`%]?
M4T1!5$%?0D5'24Y?7P!P87)?8W5R<F5N=%]E>&5C`&UY7W!A<E]P;`!P87)?
M96YV7V-L96%N`'!A<E]D:7)N86UE`'!A<E]F:6YD<')O9P!P87)?9&EE`%A3
M7TEN=&5R;F%L<U]005)?0D]/5`!X<U]I;FET`%]S=&%R=%]C`'-H85]U<&1A
M=&4`<&%R7VUK=&UP9&ER`'!A<E]C;&5A;G5P`%]?0E-37T5.1%]?`%]?8G-S
M7W-T87)T`'!A<E]S971U<%]L:6)P871H`'!A<E]C=7)R96YT7V5X96-?<')O
M8P!?7T1!5$%?0D5'24Y?7P!?961A=&$`7V5N9`!P87)?8F%S96YA;64`9V5T
M7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<VAA7VEN:70`<VAA7V9I;F%L`"]U
M<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#3U)%`+BK`````````P````````!,
M'P```````,"K`````````P``````````'P```````-"O`````````P``````
M``#P'`````````"P`````````P``````````L````````!BP`````````P``
M``````!X30```````""P`````````P````````#@3P```````"BP````````
M`P````````#H3P```````#"P`````````P````````#P3P```````#BP````
M`````P````````#X3P```````$BP`````````P``````````4````````("O
M`````````@````8``````````````(BO`````````@````<`````````````
M`)"O`````````@````P``````````````)BO`````````@```!8`````````
M`````*"O`````````@```!@``````````````*BO`````````@```!P`````
M`````````+"O`````````@```!\``````````````+BO`````````@```"$`
M`````````````,"O`````````@```"P``````````````,BO`````````@``
M`"X``````````````-BO`````````@```#```````````````."O````````
M`@```#0``````````````.BO`````````@```#<``````````````/"O````
M````"P```#X``````````````/BO`````````@```$@``````````````+BM
M````````!0````(``````````````,"M````````!0````,`````````````
M`,BM````````!0````0``````````````-"M````````!0````4`````````
M`````-BM````````!0````@``````````````."M````````!0````D`````
M`````````.BM````````!0````H``````````````/"M````````!0````L`
M`````````````/BM````````!0````T```````````````"N````````!0``
M``X```````````````BN````````!0````\``````````````!"N````````
M!0```!```````````````!BN````````!0```!$``````````````""N````
M````!0```!(``````````````"BN````````!0```!0``````````````#"N
M````````!0```!<``````````````#BN````````!0```!D`````````````
M`$"N````````!0```!H``````````````$BN````````!0```!L`````````
M`````%"N````````!0```!T``````````````%BN````````!0```!X`````
M`````````&"N````````!0```"```````````````&BN````````!0```",`
M`````````````'"N````````!0```"0``````````````'BN````````!0``
M`"4``````````````("N````````!0```"8``````````````(BN````````
M!0```"<``````````````)"N````````!0```"@``````````````)BN````
M````!0```"D``````````````*"N````````!0```"H``````````````*BN
M````````!0```"L``````````````+"N````````!0```"T`````````````
M`+BN````````!0```"\``````````````,"N````````!0```#$`````````
M`````,BN````````!0```#(``````````````-"N````````!0```#,`````
M`````````-BN````````!0```#4``````````````."N````````!0```#8`
M`````````````.BN````````!0```#@``````````````/"N````````!0``
M`#D``````````````/BN````````!0```#H```````````````"O````````
M!0```#L```````````````BO````````!0```#P``````````````!"O````
M````!0```#T``````````````!BO````````!0```#\``````````````""O
M````````!0```$```````````````"BO````````!0```$$`````````````
M`#"O````````!0```$(``````````````#BO````````!0```$,`````````
M`````$"O````````!0```$0``````````````$BO````````!0```$4`````
M`````````%"O````````!0```$8``````````````%BO````````!0```$<`
M`````````````&"O````````!0```$D``````````````&BO````````!0``
M`$H``````````````'"O````````!0```$L`````````````````````````
MEY,``#,#PT$#OH-%$P-#_9."@T434Q,`@[*"`&<`#@`7G@```SZ.1&<##@`3
M````%YX```,^#D1G`PX`$P```!>>```#/HY#9P,.`!,````7G@```SX.0V<#
M#@`3````%YX```,^CD)G`PX`$P```!>>```#/@Y"9P,.`!,````7G@```SZ.
M06<##@`3````%YX```,^#D%G`PX`$P```!>>```#/HY`9P,.`!,````7G@``
M`SX.0&<##@`3````%YX```,^CC]G`PX`$P```!>>```#/@X_9P,.`!,````7
MG@```SZ./F<##@`3````%YX```,^#CYG`PX`$P```!>>```#/HX]9P,.`!,`
M```7G@```SX./6<##@`3````%YX```,^CCQG`PX`$P```!>>```#/@X\9P,.
M`!,````7G@```SZ..V<##@`3````%YX```,^#CMG`PX`$P```!>>```#/HXZ
M9P,.`!,````7G@```SX..F<##@`3````%YX```,^CCEG`PX`$P```!>>```#
M/@XY9P,.`!,````7G@```SZ..&<##@`3````%YX```,^#CAG`PX`$P```!>>
M```#/HXW9P,.`!,````7G@```SX.-V<##@`3````%YX```,^CC9G`PX`$P``
M`!>>```#/@XV9P,.`!,````7G@```SZ.-6<##@`3````%YX```,^#C5G`PX`
M$P```!>>```#/HXT9P,.`!,````7G@```SX.-&<##@`3````%YX```,^CC-G
M`PX`$P```!>>```#/@XS9P,.`!,````7G@```SZ.,F<##@`3````%YX```,^
M#C)G`PX`$P```!>>```#/HXQ9P,.`!,````7G@```SX.,6<##@`3````%YX`
M``,^CC!G`PX`$P```!>>```#/@XP9P,.`!,````7G@```SZ.+V<##@`3````
M%YX```,^#B]G`PX`$P```!>>```#/HXN9P,.`!,````7G@```SX.+F<##@`3
M````%YX```,^CBUG`PX`$P```!>>```#/@XM9P,.`!,````7G@```SZ.+&<#
M#@`3````%YX```,^#BQG`PX`$P```!>>```#/HXK9P,.`!,````7G@```SX.
M*V<##@`3````%YX```,^CBIG`PX`$P```!>>```#/@XJ9P,.`!,````7G@``
M`SZ.*6<##@`3````%YX```,^#BEG`PX`$P```!UQANRFY*J'HNC*X$[\EY0`
M`(.T)"@NZ#+D#`@P`&@(/LZ<8#[T@4?O\)_:%Y8```,VQBNRA1>5```#-24F
M[_`_\)>7``"#MV<F@\<'`.G/EY<``(.W!RL7E```$P0$-)*7F&-R28-'ITL;
M!4D`#@63YS<`(PWW2N_PG_/"91>6```#-J8M\D<#N`4`JH87-P``$P>G)1<U
M```3!:4DF.X4Y".P!@&(YI#J!4<-*6-6]PRA!1N%-P`11Y!ADQ<W`+:7!2>0
MXZ$%XQFG_@X'"&PVER,P!P!*A@%'EP4``).%!5?O\/_)/<4(;),)00+O\#_=
M*HG.A1<U```3!27R[P!@&"G-"&SO\+_L[_!_Z2)WG&"YCP%'O>?F8$9DIF3B
M>4J%!FDE88*`[_"?W1>4```3!,0F".PAQ>_PG[^7EP``@[=''(5F,X='`!AC
M-I<C"P>6.;<(;._PO\UYMPAH`<7O$`!61;?.A1<U```3!87C[P!`$0CH6=7E
MMQ%'@;\%1>_P']OO\-^^EZ$``).!@9@*A9>5``"3A674$W$!_PF@#$$3!H4`
M@4<7EP```S>'%)>6``"#M@80%Y4```,UA1)!NQ>5```3!>49EY<``).'9QEC
MB*<`EY<``(.WIP^1PX*'@H`7E0``$P7%%Y>5``"3A447B8V3US5`_9&^E86%
MF<67EP``@[=G#)'#@H>"@)>7``"#QP<5J>-!$0;DEY<``(.W)PB1QQ>5```#
M-84.@I?O\!_YEY<``(.WIPB1QQ=U```3!87S@I>B8(5'%Y<``",)]Q!!`8*`
M@H"7EP``@[?'"IG/01$&Y)>5``"3A>4/%W4``!,%9?""EZ)@00&5MXVW.7$&
M_"+X6N"7EP``@[?'`@.[!P!C`0L(2O!.[%+H@T<%`*J)+HHJB1,'T`.]PV.&
MYP"#1QD`!0G]^SL).4$#-`L`(<PF]%;DVH23"M`#2H;.A2*%[_"?LK,')`$)
MY8/'!P!C@%<#@&2A!'7PHG0">>)I0FJB:N)P(H5"=`)K(6&"@+.$9$&-A`4)
M(R":`$J4\;\!26VW`43YOP)YXFE":MF_<7$B\2;M!O67E```@[0D]BP`G&`^
MY8%'*H3O\!^J#>'B1[UF$6?UCV.%YP`I9V.:YP`BA8E%[_!?NQ,U%0`1H`%%
M*F><8+F/`4>1YZIP"G3J9$UA@H#O\%^?,7%*\0;]%YD```,YJ?"#-PD`/N6!
M1QG%(OF#1P4`*H2)[TIT*F>#-PD`N8\!1V.>!PSJ<`IY*6&"@";U[_!?K:J$
M3<U.[2:%[_"?F%')@T<U`9,)-0&;AR?]&X<'`)GC`\<9`&W3@T<U`9N')_T;
MAP<`@>N#QQD`FX<G_1N'!P"URW'3(H52Z>_PG[4JBDZ%[_`?M3L%J@`))>_P
M?Y#.AB*&ES4``).%Y;&JB>_P7ZHL`$Z%[_#?J_U78PCU`.)'O6819_6/8X[G
M`DZ%[_!?G$Z%[_#_N2:%2FKO\'^/)?DFA>_P_[(BA>_PGXU*=*ITZFD-OP/'
M*0`YUVFW2G2J=!6W3H7O\-_OX;<B^2;U3NU2Z>_P_XT=<:+HIN3*X(;L3OQ2
M^%;T6O`7F0```SF)W@/'!0"#-PD`/N2!1Y,'T`,NA*J$8Q3W`!.$%0`BA>_P
M/ZDJBDP`)H7O\-_:JHEIR>_P'ZAC=44+DDH7FP```SOKW(X*`\<$`*:'DP;0
M`V,*!Q)C!M<``\<7`(4'??N%GX,Y"P`3!2H`/I76F>_P7X`CL*D`*<6#-PL`
M`\<$`!.%%`#6EY1C$P;0`R.`Y@`!Z[6@`T<%``4%HX#G`"7#MH>%!N,8Q_X3
M!]`#(X#G`(4'`T<$``4$A0>CC^?^=?LB9X,W"0"YCP%'\>/F8$9DIF0&:>)Y
M0GJB>@)[)6&"@(-'!``%!(4)HX_Y_O';@T<$``4$A0FCC_G^_?/1M[:'9;=>
M[&+H%YL```,[2]`#/`L`@S<,`*W+XH>!29AGH0?.AH4I9?^-)I.5-@"7EP``
M@Z?GVQ>7```3!V?;E>N%1RZ%',/O\._RJHLQQ9.:.0#BA5:&[_#OZ2,P>P&;
MAQD`C@>^FR.P"P#B:T)L3L+AO6*%[_`?@",PJP"JBPG-DYHY`.F_@4?QO<%%
M@4E%MU[L8NCO\`_SXFM";!VW01$BX!>4```#-"3+!N27=@``DX:&HK,'1`"(
M8Q>6```#-B;'ES4``).%I8WO\*_T$I0(8`)DHF`7-P``$P=GQ;J&@4<7%@``
M$P:FYI<U``"3A26-00%O\`_GEY<``(.WQ\67=@``DX9&G1>6```#-D;"DI>(
M8Y<U``"3A86(;_"/[SEQ^7*)9P;\(OA*\";T$X>'`1:1"I<7F0```SGINH,W
M"0`<XX%'[_#OW"``A66JAH4%(H47-P``$P<'B!<V```3!@:([_`/VOU78PGU
M"(5G8^6G"(5GP0>S!/$`(H4%9J:%[_`OW!L$!0!C200&&P44`._P+]ZJAS7!
M8W:5`#,'A0!C[.0$!6=!!PJ78V3W!`5G!0=C8X<$!6=!!R*&/H6S!>$`[_`/
MUBJ4JH<C``0`"6=A!PJ7%&,#-PD`-8^!1@7CB6(6D>)P0G2B=`)Y/H4A88*`
M(I?C_>?Z`I"!1\F_[_!/W#&_%7']<H5GHNFFY<KA6O&&[4[]4OE6]5[M8ND3
MAX<(%I$*EQ>;```#.\NK*HDNA!<E```3!05\3`"#-PL`'..!1^_P/ZFJA),%
M\`)*A>_P+_@QP1<E```3!<5ZRH7O\)_(2H6%9Y.'APB*EYAC@S<+`+F/`4=C
MGP<2A6(6D>Y@3F2N9`YIZGE*>JIZ"GOJ:TIL+6&"@"*%[_"/XI<E``"3A45W
M[_#/WBJ$3=6%:9.'"0F*E[.+-T&#1P0`$PJ!"),*@0"]PY'$HH4FA>_P3^(I
MP2*%[_#/[9,']?^BERJ,DP;P`F-H]``QJ".`!P#]%V,&]``#QP<`XPG7_B*%
M[_`OZRJ,2H7O\*_J8I4)!6-E-067)0``DX7E;P%%[_!/URJ$#=F#1P0`V?^9
MR(/'!`";AR?]&X<'`)GC`\<4`'';2H4%3._PS^9BE0D%%R0``!,$Q&GC?S7[
MHH;*AQ<G```3!\=K%R8``!,&QFN%95*%[_`/N04E8_.I``*0UH52A>_P#]Q9
M]8.GB_B]9B%G]8_CD>?XA452A>_PC]P]^=*%%R4``!,%!6;O\/^S4H7O\"_1
M3;WO\,_`01&3!?`"(N`&Y"J$[_#/P1G!$P05`"*%`F2B8$$!;_"OSGEQA6?]
M<DKH!O0B\";L$X>'`!:1%YD```,Y*8\*EX,W"0`<XX%'4<&#1P4`JH2US^_P
M;]H%!85G8^*G"B``IH4BA>_P3ZLBA>_P[]B3!_7_HI<BA9,&\`)C:/0`$:@C
M@`<`_1=CAJ<``\<'`.,)U_X@`"*%DP7P`N_P[[@=Q6-LI`0H`._P+\:%9Z$'
MBI>88X,W"0"YCP%'H>>%8A:1HG`"=.)D0FE%88*`A6>A!XJ7F&.#-PD`N8\!
M1YWCA6(6D:)P`G3B9$)I%R4``!,%951%86_P3\$C``4`9;<!16VW[_!OL'EQ
M(O`F[$KH!O27E```@[2$@9Q@/N2!1T``%YD```,Y"8.BA1<E```3!654[_"O
M_@W%$D>#-PD`#@>ZEYAGF.-MTYAKH0>8XVW_HH47)0``$P7E4>_P+_QI_1>)
M```#.0E_HH47)0``$P5E4>_PK_H-Q1)'@S<)``X'NI>89YCC;=.8:Z$'F.-M
M_Z*%%R4``!,%Y4[O\"_X:?T7B0```SD)>Z*%%R4``!,%Y4WO\*_V#<421X,W
M"0`.![J7F&>8XVW3F&NA!YCC;?^BA1<E```3!65+[_`O]&G]%XD```,Y"7>B
MA1<E```3!>5*[_"O\@W%$D>#-PD`#@>ZEYAGF.-MTYAKH0>8XVW_HH47)0``
M$P5E2._P+_!I_1>)```#.0ESHH47)0``$P5E1^_PK^X-Q1)'@S<)``X'NI>8
M9YCC;=.8:Z$'F.-M_Z*%%R4``!,%Y43O\"_L:?T7B0```SD);Z*%%R4``!,%
M943O\*_J#<421X,W"0`.![J7F&>8XVW3F&NA!YCC;?^BA1<E```3!>5![_`O
MZ&G]%XD```,Y"6NBA1<E```3!>4X[_"OY@W%$D>#-PD`#@>ZEYAGF.-MTYAK
MH0>8XVW_HH47)0``$P5E-N_P+^1I_1>)```#.0EGHH47)0``$P5E/>_PK^(-
MQ1)'@S<)``X'NI>89YCC;=.8:Z$'F.-M_Z*%%R4``!,%Y3KO\"_@:?T7B0``
M`SD)8Z*%%R4``!,%93KO\*_>#<421X,W"0`.![J7F&>8XVW3F&NA!YCC;?^B
MA1<E```3!>4W[_`OW&G]%XD```,Y"5^BA1<E```3!64W[_"OV@W%$D>#-PD`
M#@>ZEYAGF.-MTYAKH0>8XVW_HH47)0``$P7E-._P+]AI_1>)```#.0E;HH47
M)0``$P7E*>_PK]8-Q1)'@S<)``X'NI>89YCC;=.8:Z$'F.-M_Z*%%R4``!,%
M92?O\"_4:?VBA1<E```3!>4P[_`OTZJ%&<47)0``$P7E+>_P3_.BA1<E```3
M!84P[_!/T:J%&<47)0``$P4%,>_P;_&BA1<E```3!24Q[_!OSZJ%'<D7)0``
M$P6E(._PC^\B9YQ@N8\!1Z'C`G2B<.)D0FF7)0``DX7%,!<E```3!<4D16%O
M\`_MHH47)0``$P7%+>_P#\NJA6'5%R4``!,%Q23O\"_K;;_OX'_X`1$BZ`;L
M%X0```,TQ$E,`!<E```3!:4B'&`^Y(%'[_"/QQ7!@T<%``%%B<>3AP?],S7P
M`")G'&"YCP%'F>?B8$)D!6&"@`%%];?OX)_S%X,```,SPTL=<2J.`S4#`"[T
M$P.!`C+X!NSRA3;\%XX```,^;D.ZX+[DPNC&[!J&@S<.`#[D@4<:X._PKY83
M!?`/[_`OBUUQP7+!9TKX3O12\(;DHN`F_%;L6N@3AX<`%I$*EQ>*```#.@H_
M@S<*`!SC@4<)1H%%JHGOX+_J$PGU_Q-7^4-!D[,'Z0#"%\&3F8\S"?E`8T4)
M"(J$_5H=2P%&RH5.A>_@_^=C`U4)068A!J:%3H7OX/_O`25C!%4'8WRK!&$5
M,X2D`&-VE`"IH'T48V.4!"%&EX4``).%14`BA>_@/_-M]3,%)$!*E<%GH0>*
MEYAC@S<*`+F/`4>=[\%B%I&F8`9DXG1">:)Y`GKB:D)K86&"@,%W/IGC$OGX
M?57QMQ<E```3!847[_!?[1<E```3!<45[_"?[._@G]]!$0;D[^`?V._@W_(1
MP0AAHF!!`8*`.7$F]$KP!OP7B0```SEI+ZJ$3``7)0``$P4E%(,W"0`^Y(%'
M[_#OK!G%(OB#1P4`*H2=XT)T(F>#-PD`N8\!1Z:%%R4``!,%11&]X^)PHG0"
M>2%A;_`/RR:%3NSOX#_WJHDBA>_@O_9.E0D%[^`_TB*')H:7)@``DX:F^Y<E
M``"3A27\*H3OX)_K(F>#-PD`N8\!1Y7CHH5"=.)IXG"B=`)Y%R4``!,%10LA
M86_PC\4B^$[L[^"_TN_@?]*7AP``DX>G+`.XAP,)<0._!P&#OH<!`[X'`@.S
MAP*#N`<#RO+.[M+JAOZB^A,)P0`7B@```SHJ(:J)%R8``!,&A@>7)@``DX:&
M\!<G```3!P<'ER<``).'!P?"],J%%R4``!,%1>\#.`H`0O8!2`+P`OSZX/;D
M\NB:[,;P,N@V[#KT/OCO\"^;$<6#1P4`*H1CE@<<IO;6YN_@O\'OX'_<8P0%
M%`!A8P$$%"*%[^!_Y@8%!07OX/_!`T8$`*J$JHH)SB:%ER4``).%Y0#OX'_;
M`T84``4$B01M]H0`%R4``!,%Y?4AH(ADH00-P<J%[_"/E"J$;=F#1P4`]=?O
M\,^=?=$BA>_@_]$JA!'M!`B`8!G(@T<$`/G'(H7O\.^;1>V`9*$$??0BA>_@
MO]ZJA%:%[^`_WJF<FX1$0":%[^!_N=:'(H87)P``$P=G^9<F``"3AN;BER4`
M`).%Y?BJBN_@7])6A9,%`!SOX+_@_5=C&/4`[^`?UAA!Q4=C$O<,C!A6A>_@
M'\$JA!GEBD>]9A%G]8]CCN<(EX<``(.W1Q$#M@D`B&/6AI<E``"3A<7X[^!?
MNX%$,G>#-PH`N8\!1V.<!RSV<%9TMFH6>?9I5FHFA;9T&6&"@"*%[^"_Q"J$
MH00=U9&W`42!MR00B&`9R<J%[_!OA`'%@T<%`(7CB&2A!'WU-47OX/^LJH2J
MBA<D```3!.3I$P8P!6VU[^"?P"J$H01AU>_@_\X&!04%8;7:XBI+[^`?J&,%
MJP06:ZF_EX<``(.WQP8#M@D`B&/6AI<E``"3A47J[^#?L*&_[_"?SC)W@S<*
M`+F/`4=CF@<B(H56=/9P%GGV:59J&6%OX'^ZBD=>_A,'`!R3]_<?8X7G`!9K
M\GL)MR:%[^"_H\J%JH07)0``$P6E[N_@__BJA6,'!1`#M0D`[_#ORJJ+8P`%
M$%Z%[^`?Q1L+!0"-1V/89P,3!<O_7I67)0``DX7%Z^_@7[<)[9%'8PS[%IL'
MN__>EP/'!P"3!_`"8P/W%LJ%%R4``!,%Q<WOX!_S1<V#1P4`S<L3!P`#8X;G
M"I<E``"3A875%R4``!,%A<OO\.^1[^!?E"J'5H8FA9<G``"3AR?UER8``).&
MIL.7)0``DX6EY^_@/[-]6<5)':COX)^W'$%CGC<#[^#_D`4D*H>BAU:&)H47
M*```$PB(\9<F``"3A@;`ER4``).%!>7OX)^ODP4`'":%[^#_O>,!)?U6A>_@
M7\"FA1<E```3!>6Z[_#/B2:%[_`_N19K\GOMNX.["0`!MUZ%@47OX-^U*HDY
MU>_P?Z:JB>-#!?23!67_`49*A>_@/Y,3"P$/VH5*A1E&[^!?FYE'8QOU"$Y7
MMT=!0Y.'!S#C'/?P`U=+`)%GDX>'5.,5]_"3A>G\`49*A>_@?X^@&4J%HH43
M!H`"[^"?EY,'@`)C'/4$(H>7)P``DX<GY9<F``"3AJ:S5H:7)0``DX6%UB:%
M(P`!$N_@OZ*!MX.YB0#CC0GH3H7OX+^JC4?C]Z?H<15.E9<E``"3A472[^!?
MG>,=!>;.BY6]%R4``!,%A='O\-^5VN)>_N_@GXBF]M;FVN)>_N_@WX<Y<2+X
M%X0```,T1.!*\$[L!OPF]%+HLP=$`(1CDPE!`!>)```#.8G7@\<$"\Z%%R4`
M`!,%):X#-PD`.N0!1Z.(]`KOX+_4&<4#1P4`DP<0`V,)]Q+O\"_2LP=$`(1C
M)H6-1@5&ER4``).%Q<WOX-^7JH0=P1QI,P=$``ACC&,7)@``$P:FS._@/X*<
M:(QCW$43EY<"8TP'$+,'1`"(8XU&!4:7)0``DX7ERN_@_Y.JA!>*```3"@K?
M#<'.A1<E```3!<6?[^"?S"J&:<&<:#,'1``(8XQC[^`O_;,'1`"$8P5&ER4`
M`).%9<<FA>_@WX>JA1<F```3!N;')H7OX,_Z$I0<8,Z%%R4``!,%)9JCB`<*
M[^"_QR,XJ@`YQ9,%`!SOX)^:&P<5`(5'8_'G`L5'8P[U`(,WB@`#-@H!JH:,
M8Q<E```3!07&[^`/Y2)G@S<)`+F/`4>]Y^)P0G2B=`)YXFE":B%A@H`#-8H`
M[_"_GB,XJ@!%]1<E```3!27`[^"OX8-'%0#CC`?LZ;7O\(^$F&BS!T0`JH0,
M8XACD<PFAN_@C_`FA>_@/Y4%O[,'1`"(8^_@;^/-M8,WB@"08^_@K^XAO^_@
M3^MY<2+P)NP&]!>$```#-(2\JH1,`!<E```3!465'&`^Y(%'[^`_N@'-@T<%
M`(G+$P<``V.&YP"!Q(/'!`"9ZR)G'&"YCP%'H>^B<`)TXF1%88*`)H5*Z._P
M3Z>3!?`"*HGOX`_G&<$3"14`2H7OX$_T$4:7)0``DX5EG^_@;^P9P4)I=;\B
M9QQ@N8\!1Y'K`G1"::)P)H7B9$5A;^!_PDKH[^`/X1,!`=27@P``@[.#LC0`
MP6XC/!$J(SB!*B,TD2HC,"$K(SPQ*9,(A0.3#X4'@[<#`",T\2B!1S:(DXX.
M\#</_P`#M@@`H0A!")-5!@(3%X8!$Y.%`9,2A@"35X8"`A<37H8`$U2&`P&3
M`A.S\N(!L_?7`1-3`P(S9U<`,W[>`:(%P8\S9\<!&U:&`;/UY0&SYV<`48_-
MCR,XZ/XC//C^XY$?^T9_YGX*9V)N`G.B>$)XXG6&;Q.$!B`1H+*/L&*<8KJ"
MH0:QC[/'YP&SQ\<!$Y<7`/V#78\"%P&3N/X:CG:/1H.6CL*(+HC^A>,8U/P0
M80QI`SB%`2)N@SB%``,S!0*35[8!$Q=6`#>/@EH3#Y^978]ZGK/&!0$"%QJ>
MD]XH``&3DY?H`;/V%@&SY]<!<I>SQ@8!-I<3G@<"PF837@X"DQ\'`C/'Q0&3
MWP\"<8_ZEI/2OP&3GE\`+8_"EK/N7@`35"8`XF(VEY,6Y@'!CG:7DQX'`K6/
MD]X.`C.'X@&S]_<!$]2^`2Z7DY)>`+/'QP&SXH(`NI<"=!.7[P&3WR\`,V?W
M`9:7@A>3D@8"N8Z!D[,/Y`&3T@("L_;6`7Z>$]2W`9.?5P"SQE8`\I8S[H\`
M\I:B?Q.>[@&3WBX`,V[>`1,4!P*"%C-'QP&!D@&0LX[O`7V/EIZ3GU8`D]*V
M`2&/=I>S[E\`=I?"?Y.>YP&)@[/N_@"S1]X!DQ(.`@(7`9.3T@(",X[O`?6/
M(IZ3'U<`$U2W`;/'5P#RES/NCP#RE^)_$Y[F`8F",V[>`+/&S@$3E`X"@A>!
MDP&0LX[O`?F.EIZ3GU<`D]*W`:&.]I:S[E\`]I:&;Y,>YP$)@[/N[@`S1]X!
MDQ(.`H(6@9*3T@(",X[O`7V/(IZ3GU8`$]2V`3-'5P!RES/NCP!REZ9O$Y[G
M`8F#,V[^`+/'S@$3E`X"`A<!DP&0LX[O`?6/EIZ3'U<`DU*W`:&/]I>S[E\`
M]I?&;Y.>Y@&)@K/NW@"S1MX!DQ(.`H(7@9.3T@(",X[O`?F.(IZ3GU<`$]2W
M`;/&5@#REC/NCP#REN9O$Q[G`0F#,V[N`#/'S@$3E`X"@A:!D@&0LX[O`7V/
MEIZ3GU8`D]*V`2&/=I>S[E\`=I>&?Y.>YP&)@[/N_@"S1]X!DQ(.`@(7`9.3
MT@(",X[O`?6/(IZ3'U<`$U2W`;/'5P#RES/NCP#REZ9_$Y[F`8F",V[>`+/&
MS@$3E`X"@A>!DP&0LX[O`?F.EIZ3GU<`D]*W`:&.]I:S[E\`]I;&?Y,>YP$)
M@[/N[@`S1]X!DQ(.`H(6@9*3T@(",X[O`7V/(IZ3GU8`$]2V`3-'5P!RES/N
MCP!RE^9_$Y[G`8F#,V[^`+/'S@$3E`X"`A<!DP&0LX[O`?6/EIZ3'U<`DU*W
M`:&/]I>S[E\`]I>*;Y.>Y@&)@K/NW@"S1MX!DQ(.`H(7@9.3T@(",X[O`?F.
M(IZ3GU<`$]2W`;/&5@#REC/NCP#REJIO$Q[G`0F#,V[N`#/'S@$3E`X"@A:!
MD@&0LX[O`7V/EIZ3GU8`D]*V`2&/=I>S[E\`=I>3G^<!RFZ)@[/O_P"S1_X!
MDQ(.`@(7`9.3T@(",X[N`?6/(IZ3'E<`$U2W`;/'5P#RES/NC@#RE^ID$]XF
M`).>Y@&"%X&3L^[.`1/9MP&SQM\!$Y0/`A.>5P`!D+./Y`$S;BX!^8Z6GZ&.
M`AX37@X"_I;RE@IY$UXG`).2!@*3'^<!D]("`K/OSP$SQ_X!DY0.`A.>4@"S
M#ND!$]^R`8&0,V[N`7V/HIXECP(>$UX.`G:7$Y3G`8F#<I==C+/'CP"J?A,9
M!P(360D"M8^W]MENDX86NA-?N0$3'ED`,V[N`;:>@A>FGH&3`A[VEQ->#@(^
MGA.?X@&3TB(`,V]?`,IWDQ0.`H&0LT[D`9/2M`&SSNX`@A\3EU0`D]\/`C-G
M5P"VEX(>D]X.`OZ7`A?VEP&3/I>3'ND!$UDI`+/N+@'J=Y,2!P*3T@("LT_?
M`1/9L@&SS\\!`A03GE(``9`S;BX!MI>"'Y/?#P*BEP(>_I<37@X"/IZ3G^0!
MB8"S[Y\`CF<3%`X"`9"SQ/X!$UFT`;F,`A\3%U0`$U\/`C-G)P&VEX(4@9#Z
MEP(7II<!DSZ7$Y_B`9/7(@`S;_\`DQ('`JYGD]("`K/$[P$3V;(!L\3$`8(>
M$YY2`)/>#@(S;BX!MI>"%(&0]I<"'J:7$UX.`CZ>DQ[D`9-7)`"S[OX`$Q0.
M`LYG`9"S1-\!$UFT`;F,@A\3%U0`D]\/`C-G)P&VEX(4@9#^EP(7II<!DSZ7
MDY_B`9/7(@"S[_\`DQ('`NYGD]("`K/$_@$3V;(!L\3$`0(?$YY2`!-?#P(S
M;BX!MI>"%(&0^I<"'J:7$UX.`CZ>$Q_D`9-7)``S;_\`$Q0.`HYW`9"SQ.\!
M$UFT`;F,@AX3%U0`D]X.`C-G)P&VEX(4@9#VEP(7II<!DSZ7DY[B`9/7(@"S
M[OX`DQ('`JYWD]("`K-$WP$3V;(!L\3$`8(?$YY2`)/?#P(S;BX!MI>"%(&0
M_I<"'J:7$UX.`CZ>DQ_D`9-7)`"S[_\`$Q0.`LYW`9"SQ/X!$UFT`;F,`A\3
M%U0`$U\/`C-G)P&VEX(4@9#ZEP(7II<!DSZ7$Y_B`9/7(@`S;_\`DQ('`NYW
MD]("`K/$[P$3V;(!L\3$`8(>$YY2`)/>#@(S;BX!MI>"%(&0]I<"'J:7$UX.
M`CZ>DQ[D`9-7)`"S[OX`$Q0.`I)G`9"S1-\!$UFT`;F,@A\3%U0`D]\/`C-G
M)P&VEX(4@9#^EP(7II<!DSZ7DY_B`9/7(@"S[_\`DQ('`K)GD]("`K/$_@$3
MV;(!L\3$`0(?$YY2`!-?#P(S;BX!MI>"%(&0^I<"'J:7$UX.`CZ>$Q_D`9-7
M)``S;_\`$Q0.`M)G`9"SQ.\!$UFT`;F,@AX3%U0`D]X.`C-G)P&VEX(4@9#V
MEP(7II<!DSZ7DY[B`9/2(@"S[EX`\F>3%`<"@9"S0M\!$]FT`;/"P@&"'Q.>
M5`"3WP\",VXN`;:7@A*3T@("_I<"'I:7$UX.`CZ>DQ+D`9-7)`"SXO(`$Q0.
M`I)W`9"SSUX`$UFT`;//[P`"'Q,75``37P\",V<G`;:7@A^3WP\"^I<"%_Z7
M`9,^EY.?Y`&)@+/OGP"R=Q,9!P(360D",\_R`9-4N0$S3\\!@AX3'ED`D]X.
M`C-NG@"VEP(?$U\/`O:7`A[ZEQ->#@*SCL<!$Q_D`0F`,V^/`-)WDY0.`H&0
M,\[O`1/4M`$S3NX`@A(3EU0`D]("`D&/MI<"'A->#@*6EP(7`9,3%.D!\I<3
M62D`,V0D`3..YP!R=[-'CP"SQ]<!@A^3'@X"D]X.`I/?#P(VEX(7$]F^`8&3
M?I>3GUX`/I>3DN0!L^<O`8F`L^*2`#Z7EF>S3U0`DQ0/`C/.SP$3'P<"$U\/
M`H&0MI<"'I-?OP$37@X"II>3%E\`L^;V`1.7[@'REY/>+@`S9]<!MI>V;K?V
MQB.3'P<"$YX'`I.7)@"3A\?-D]\/`K/FX@`"%!->#@*S]/(!`9"^GK/VY@&B
MGL6.$Q1>`)-4O@'VEK-NE`#VEE9DDQ3O`9->+P"S[M0!$Y\"`C-GUP&3D@8"
MD]("`K,&]``S=\<!,_3^`1-?#P(VGY/4L@%!CQ.44@"3%NX!>I<37BX`,V^4
M`+/FQ@%ZEW9O$Y0&`@&0,^[>``(7`9.S](X`/I\S?EX`?I\S;IX`DQ]7`)-4
MMP%ZGC/OGP!ZGI9T$YGB`1/?(@`S;^D!DQ\.`K/FY@&"'I/?#P*S<H\`,X[T
M`)/>#@+YCG:>L^96`!/9OP&3DE\`DQ3G`9->)P`SA\8!L^;4`3/N(@&V?G*7
MDY(&`I/2`@(S;M\``A<!D[-T7P"^GC-^_@&BGC-NG@`3%%<`DU2W`7:>LVZ4
M`%9TDY3O`9/?+P"S[_0!=IZ3'@X"L^;V`0(?D]X.`C,.]``37P\",_1?`/F.
M>I[!CA/9O@$3E%X`DQ3G`1-?)P`SA\8!L^;D`3-N)`%V?W*7$Y0&`@&0,^[?
M``(7`9.S](\`/I\S?MX!%I\S;IX`DQ)7`)-4MP%ZGC/OD@":8I.4[@&3WBX`
ML^[4`7J>$Q\.`K/FU@&"'Q-?#P(SCO(`D]\/`K/RC@#YCGZ>L^96`!-9OP&3
M$E\`DQ3G`9-?)P`SA\8!L^;T`3/N(@&Z;W*7DY(&`I/2`@(S[MX``A<!D[/T
M7@"^GS-^[@&BGS-NG@`3%%<`DU2W`7Z>LV^4`%IDDQ3O`1-?+P`S[^0!?IZ3
M'PX"L^;F`8(>D]\/`C,.]`"3W@X",W1?`/F.=I[!CA/9OP$3E%\`DQ3G`9->
M)P`SA\8!L^;4`3-N)`'Z;G*7$Y0&`@&0,V[?``(7`9.S=(\`OIXS?OX!EIXS
M;IX`DQ)7`)-4MP%VGK/ND@":<I.4[P&3WR\`L^_T`7:>DQX.`K/F]@$"'Y/>
M#@(SCO(`$U\/`K/RCP#YCGJ>L^96`!/9O@&3DEX`DQ3G`1-?)P`SA\8!L^;D
M`3/N(@$Z?W*7DY(&`I/2`@(S[M\``A<!D[/T7P`^GS-^W@$BGS-NG@`3%%<`
MDU2W`7J>,V^4`%ITDY3N`9/>+@"S[M0!>IX3'PX"L^;6`8(?$U\/`C,.]`"3
MWP\",_1>`/F.?I[!CA-9OP$3%%\`DQ3G`9-?)P`SA\8!L^;T`3-N)`'Z?W*7
M$Y0&`@&0,^[>``(7`9.S](X`OI\S?NX!EI\S;IX`DQ)7`)-4MP%^GK/OD@">
M8I,4[P$37R\`,^_D`7Z>DQ\.`K/FY@&"'I/?#P(SCO(`D]X.`K-RCP#YCG:>
MD]2_`9.>7P"SYE8`DQ+G`0F#,^?B`/*6,^Z>`+YN\I:3$@<"D]("`C-N[P""
M%H&2LW1?`+Z>,W[^`:*>,VZ>`!.45@"3U+8!=IZS;I0`=IY>9).4[P&3WR\`
MDQX.`C/N]`$S9\<!`A^3W@X"LP_T`'6/,W1>`!-?#P)^GT&/DY]>`!/4O@%Z
MES/OCP#^9'J7$Y_F`8F"LV;?``(7`9.3GP8"D]\/`C-OW@`36;<!OI03%%<`
MII(S9"0!LW3^`3-_WP$S;Y\``A0!D!:?GG0BGY,2#P*3T@("$Y3N`9/>+@`S
M9-0!OI23GE(`D]>R`<&.L^[^``(>L_?F`!->#@*3E@X"LW[T`2:>L^?7`?*7
M@9*^EI,4YP$)@]F,$YD&`KY^M[>8,A-9"0(S1Y0`B@>3AV<=,T?G`1,>60`3
M7[D!,V[N`;Z>`A?^G@&3`AX37@X"=I>S#L<!$Y_B`9/2(@`S;U\`DYD.`EY^
MD]D)`C/'Y`&3W[D!-8\"%).660`!D+/F]@$^G@(7(IX!DX(6@9)RES,.UP"3
M'^D!$UDI`+/O+P&3$@X"?G>3T@("LT;_`1/4L@&SSM8!@A23EE(`@9#!CCZ7
M@AZ3W@X")I>"%G:7@9*ZEI.>Z0&3V2D`L^X^`1.4!@(#-P$@`9"SQ-\!$UFT
M`;/$Q`$"'Q,>5``37P\",VXN`3Z7@A2!D'J7`AXFEQ->#@(ZGA.?X@$3UR(`
M,V_O`),2#@(#-X$@D]("`K/$[@$3V;(!M8R"'Y.64@"3WP\"L^8F`3Z7@A2!
MD'Z7@A8FEX&2NI:3'^0!$U<D`+/O[P`3E`8"`S<!(0&0LT3_`1-9M`&SQ,0!
M@AX3'E0`D]X.`C-N+@$^EX(4@9!VEP(>)I<37@X".IZ3GN(!$]<B`+/N[@"3
M$@X"`S>!(9/2`@*SQ-\!$]FR`;6,`A^3EE(`$U\/`K/F)@$^EX(4@9!ZEX(6
M)I>!DKJ6$Q_D`1-7)``S;^\`$Y0&`@,W`2(!D+/$[@$36;0!L\3$`8(?$QY4
M`)/?#P(S;BX!/I>"%(&0?I<"'B:7$UX.`CJ>DY_B`1/7(@"S[^\`DQ(.`@,W
M@2*3T@("LT3_`1/9L@&UC((>DY92`)/>#@*SYB8!/I>"%(&0=I>"%B:7@9*Z
MEI,>Y`$35R0`L^[N`!.4!@(#-P$C`9"SQ-\!$UFT`;/$Q`$"'Q,>5``37P\"
M,VXN`3Z7@A2!D'J7`AXFEQ->#@(ZGA.?X@$3UR(`,V_O`),2#@(#-X$CD]("
M`K/$[@$3V;(!M8R"'Y.64@"3WP\"L^8F`3Z7@A2!D'Z7@A8FEX&2NI:3'^0!
M$U<D`+/O[P`3E`8"`S<!)`&0LT3_`1-9M`&SQ,0!@AX3'E0`D]X.`C-N+@$^
MEX(4@9!VEP(>)I<37@X".IZ3GN(!$]<B`+/N[@"3$@X"`S>!))/2`@*SQ-\!
M$]FR`;6,`A^3EE(`$U\/`K/F)@$^EX(4@9!ZEX(6)I>!DKJ6$Q_D`1-7)``S
M;^\`$Y0&`@,W`24!D+/$[@$36;0!L\3$`8(?$QY4`)/?#P(S;BX!/I>"%(&0
M?I<"'B:7$UX.`CJ>DY_B`1/7(@"S[^\`DQ(.`@,W@263T@("LT3_`1/9L@&U
MC((>DY92`)/>#@*SYB8!/I>"%(&0=I>"%B:7@9*ZEI,>Y`$35R0`L^[N`!.4
M!@(#-P$F`9"SQ-\!$UFT`;/$Q`$"'Q,>5``37P\",VXN`3Z7@A2!D'J7`AXF
MEQ->#@(ZGA.?X@$3UR(`,V_O`),2#@(#-X$FD]("`K/$[@$3V;(!M8R"'Y.6
M4@"3WP\"L^8F`3Z7@A2!D'Z7@A8FEX&2NI:3'^0!$U<D`+/O[P`3E`8"`S<!
M)P&0LT3_`1-9M`&SQ,0!@AX3'E0`D]X.`C-N+@$^EX(4@9!VEP(>)I>3GN(!
M$UX.`I/2(@"S[EX`.IX#-X$GL\+?`;/&T@`"'Q-?#P*3$@X"/I>"%I/2`@*!
MDGJ7DY12`!/9L@$VEQ,?Y`&#-@$H"8`S;X\`L^0D`3/$[@$FE[:7@A\"%S-.
MQ`$!D[*7D]\/`@(>DU:W`1,65P`37@X"_I=5CO*7DY;B`9/2(@"RE[/F5@`S
M!A<!=I,SA[8`0I^"%X&3DQ8&`I,5`P(3%@\"`A>!DH&1`9(!DQSA%.4,\1#M
M@S:!*(.W`P"UCX%&&.F1[X,P@2L#-`$K@S2!*@,Y`2J#.8$I$P$!+(*`[]`/
MET$1$P4`"`;D[]!/D1=(```#.(A(MW9=3#=WZ6&&!K<E16<W5C(0!@>3AN;/
MDX45,!,&9D<3!P<?%.DC-`4"(S@%`B,L!08,X2,T!0$0[1CQHF!!`8*`77$F
M_%+P5NR&Y*+@2OA.]!AUDQ<V`+*$NI<0>8(7@9,SM^<`*HJ3UM0!*%TZEC.'
MQ@`C-/H"(SCJ`JZ*4>E:Z!,)B@,3"_`#8U^;`E[D5H23B0H$DPN*!V-PB09C
M8W0'SHJBA1,&``1*A>_0SX!2A9N$!/SOX'^I$P0$!).)"03C3)O\HFMC;UD#
M8_8J`;.'F@!C;?D"UH5*A2:&[\"__2,LF@9":Z9@!F3B=$)YHGD">N)J86&"
M@,Z*XW0D^^-R.?L"D+,'F0#C]_K\7N0"D),'``2)GQN$!P!CU/0`&X0$`!,)
MB@-*E6-\50.S!X4`LXF*`&/L^@+6A2*&[\"_]X,GB@<3!P`$H9\C+/H&XYSG
M^%*%6NB!G._@/Y_.BAVWLXF*`./ZJOSC>#7]6NA>Y`*0.7$B^";T3NQ2Z%K@
M!OQ*\%;D`[F%`H/6A0(#UP4#DU<Y`!.+A0.3]_<#D]F&`!-:AP";EH8`&Q>'
M`#,&^P`NA+/IV0"3!0#X,VKJ`(,Z!`.%)R,`M@#"&4(:$P:``ZJ$D]D)`S,%
M^P`36@H#8U7V$!,'``2[!_=`$4=C_^<0"4=C\^<08YX'#B*%[^#_E%J%$P:`
M`X%%[]#OA9-7B0$3UXH!$UD)`9/:"@$C&40'(QLT!Z,(5`<C"O0&HPHD!R*%
M(PCD!N_@7Y$<8"*%X8,C@/0`'&#!@Z.`]``<8*&#(X'T`!Q@HX'T`!QDX8,C
M@O0`'&3!@Z."]``<9*&#(X/T`!QDHX/T`!QHX8,CA/0`'&C!@Z.$]``<:*&#
M(X7T`!QHHX7T`!QLX8,CAO0`'&S!@Z.&]``<;*&#(X?T`!QLHX?T`!QPX8,C
MB/0`''#!@Z.(]``<<*&#(XGT`!QPHXGT`$)TXG"B=`)YXFE":J)J`FLA86_0
M+X\=GH%%[\"_]S&_(P`%`!&W(P`%`*,`!0#Y%SJ5XXL'[NVW(P`%`*,`!0`C
M`04`HP$%`/$7.I4)1^/KY^S1OR5S+R5S````1'EN84QO861E<CHZ8F]O=%]$
M>6YA3&]A9&5R``````!);G1E<FYA;',Z.E!!4CHZ0D]/5`````!E>&4`````
M`"]P<F]C+R5I+R5S```````N`````````%!!4E]414U0``````````!005)?
M4%)/1TY!344`````.@`````````O`````````"5S)7,E<P``4$523#5,24(`
M`````````%!%4DQ,24(`4$523#5/4%0``````````%!%4DQ)3P``4$%27TE.
M251)04Q)6D5$`%!!4E]34$%73D5$``````!005)?0TQ%04X`````````4$%2
M7T1%0E5'`````````%!!4E]#04-(10````````!005)?1TQ/0D%,7T1%0E5'
M``````````!005)?1TQ/0D%,7U1-4$1)4@````````!005)?5$U01$E2````
M````4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X``````````#$`
M````````;'-E96L@9F%I;&5D`````')E860@9F%I;&5D``````!,1%],24)2
M05)97U!!5$@`4UE35$5-```O=&UP`````%5315(`````55-%4DY!344`````
M`````"4P,G@`````<&%R+0`````E<R5S)7,E<P``````````)7,Z(&-R96%T
M:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A
M9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N
M*0H```````!0051(`````'!A<FP`````+G!A<@````!S:&]R="!R96%D````
M````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE
M=2TE=25S```````````8`````````'!E<FP`````,`````````!005(Z.E!A
M8VME<CHZ5D524TE/3@`````Q+C`V-````%5N86)L92!T;R!C<F5A=&4@8V%C
M:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C
M86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````
M```M90```````"TM````````5$U01$E2``!414U01$E2`%1%35``````5$U0
M``````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B
M?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA
M9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ
M92P@)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<
M;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B
M3B(I"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+
M7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@
M0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D
M<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ
M*2`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I
M<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D
M9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE
M;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D
M4$%27TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@
M+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L
M("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF
M("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T
M;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO
M=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z
M.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN
M:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R
M7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I
M;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE
M.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD
M)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N
M86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT
M(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R
M7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K
M(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D
M(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O
M;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B
M86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA
M;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF
M(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I
M;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E
M<WES(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG
M(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3
M,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>
M3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G
M;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?
M<V5T7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%
M3E9[4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)
M3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@
M<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I
M('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI
M.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP
M;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I
M8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@
M9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G
M;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@
M870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O
M<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`[
M"G)E860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@
M;F4@(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO
M(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;
M0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC
M7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@
M)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D
M8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F
M9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S
M:7IE("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E
M;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@
M("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&
M24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L
M(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U
M;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN
M86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<
M9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT
M*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(
M+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD[
M"FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX
M?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B
M+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA
M;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE
M;F%M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L
M;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@
M)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR
M96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D
M<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R
M("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*
M<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO
M9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE
M(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z
M.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I
M92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H
M*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D[
M"G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S
M*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I
M;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N
M86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E
M='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@
M9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO
M861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y
M.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I
M;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE
M<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I
M('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I
M;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M
M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+6DE07TU!1TE#
M*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I
M;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P
M;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O
M9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G
M9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[
M(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI
M"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO
M;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?
M=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@
M<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'
M5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%0
M4%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R
M;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD
M05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T
M.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L
M<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@
M97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@
M97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B
M=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE
M(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]
M"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R
M(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I
M9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%2
M1U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%
M3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T
M.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2
M.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI
M9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I
M<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I
M9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`[
M"FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P
M87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T[
M"F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M
M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A
M9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O
M('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%
M5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^
M(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<[
M"GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W
M)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z
M("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A
M<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q("102UI)4%]-
M04=)0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@
M24\Z.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W
M-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T[
M"B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*
M:68@*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&
M2"P@)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*
M;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.
M5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI
M+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I
M;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O
M("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A
M=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T10
M04XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\
M(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$
M>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY
M("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@
M(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C
M:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA
M;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]
M"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@
M;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y
M+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H
M+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D
M:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL
M87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@
M:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD
M("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q
M6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN
M86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@
M>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@
M/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q
M<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*
M8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N
M=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%4
M24U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL
M=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL
M92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N
M9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ
M6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG
M+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H
M<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP
M+3YW<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B
M73L*?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,
M14%.(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM
M>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`[
M"B1C='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H95]N
M86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE(#T@<W5B<W1R
M("1C86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M
M92`N/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE
M7VYA;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#04-(12(I.PI]
M"FUY("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BD["B1F
M:"T^<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#*3L*)&9H
M+3YC;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D
M;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U
M;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E
M<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*
M<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L
M90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O
M<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@
M87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3
M:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T
M:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C
M('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M
M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I
M<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64[
M"FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_
M.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM
M>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3
M<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*
M:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R
M97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE
M(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*
M?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O
M("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA
M;65D*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@
M9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?
M;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP
M=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE
M?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L
M:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;
M('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A
M<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI
M9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?
M.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T
M:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H
M)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP
M871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I
M=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6([
M"G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E
M('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U
M:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\[
M"G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR
M97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL
M93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E
M<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#
M;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@
M1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U
M:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@
M<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@
M?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V
M86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@
M>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE
M=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C
M:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-
M4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N
M("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H
M(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@
M>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@
M*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@
M)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2![
M"B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.
M5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D
M<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB
M+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE
M7V1I<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E
M;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N
M86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF
M("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I
M('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM
M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U
M9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@
M>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@
M;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D
M("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G
M.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]
M"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD
M14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI
M;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%2
M7U1%35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*
M?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I
M(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE
M<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE
M+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*
M)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M
M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP
M;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U
M<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN
M960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@
M/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@
M)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D
M14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R
M;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D[
M"GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE
M+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L
M("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R
M;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T[
M"G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP
M871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.
M5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@
M/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER
M)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M
M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P
M<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I
M"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?
M9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!2
M3T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\
M(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]
M"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C
M=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T
M0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>
M*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN
M:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@
M>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#([
M"GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!2
M3T=.04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W
M+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)]
M(#T@)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?
M1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D
M14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I
M970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E
M('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#
M;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ
M0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C
M:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD[
M"GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<
M)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q
M<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z
M($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G
M;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO
M7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?
M15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%
M4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2
M(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`'!E<FQX<VDN8P``````````
M0T%#2$4``(FKS>\``````1L#.]0````9````8(___Z0%``#DD?__[````(:2
M__]0`0``X)+__WP!``#VD___X`$``*J5__]``@``!);__V0"```LEO__>`(`
M`!"7__^L`@``$I?__\`"``#(F/__#`,``.J8__\L`P``SIG__W`#``!.G?__
MH`,``)R=___$`P``XIW__]P#``#<GO__(`0``/*>__\\!```KI___Y`$``!8
MI/__)`4``""F__]<!0``Q*;__]@%``!DN___#`8``+J[__\L!@``[+S__Y`&
M````````$``````````#>E(``7P!`1L,`@!@````&````/"0__^B`````$(.
M0$Z!`H@$EA!2D@B3"I0,9HD&E0YFR4+20M-"U$+50L%$R$+60@X`0@Y`@0*(
M!(D&D@B3"I0,E0Z6$%#)U432T]1$D@B3"I0,0M)"TT+4````*````'P````N
MD?__6@````!"#K`!1H@$B0:!`@)&"L%"R$+)0@X`0@L```!@````J````%R1
M__\6`0```$(.P`%$D@B!`EB(!$;(4,%"TD(.`$(.P`&!`H@$D@A"B09*DPH"
M0I0,`E+45`K(0LE"TT(+2--"R$+)0H@$B0:3"I0,2,C)T]1(B`2)!I,*E`P`
M7`````P!```.DO__M`$```!"#F!0B`2)!I((@0*3"I0,E0Z6$`+4"L%"R$+)
M0M)"TT+40M5"UD(.`$(+;I<2F!0"7`K70MA$"U37V$27$I@41M?81)<2F!1&
MUT+8````(````&P!``!BD___6@````!"#A!"B`1*@0)HR$+!7@X`````$```
M`)`!``"8D___*``````````P````I`$``*R3___D`````$(.0%(.P$"!`H@$
MD@B)!@*R"@Y`0L%"R$+)0M)$#@!""P``$````-@!``!<E/__`@````````!(
M````[`$``$J4__^V`0```$(.X`%>#N`AB`2)!I((EA"!`I,*E`R5#I<2F!0"
M7`H.X`%"P4+(0LE"TD+30M1"U4+60M="V$(.`$(+'````#@"``"TE?__(@``
M``!"#A!(B`2!`E#(0L%"#@!`````6`(``+:5___D`````$(.,%(.L""2"($"
MB`2)!@**"@XP0L%"R$+)0M)"#@!""U8*#C!"P4+(0LE"TDH.`$0+`"P```"<
M`@``5I;__X`#````0@XP2(@$B0:2"($"`S8#"LA"P4+)0M)2#@!$"P```"``
M``#,`@``IIG__TX`````0@X@1(@$@0)Z"L%"R$(.`$(+`!0```#P`@``T)G_
M_T8`````2@Y@4($2`$`````(`P``_IG___H`````0@Y06@[0@`22"),*E`R!
M`H@$B0:5#I80`J(*#E!"P4+(0LE"TD+30M1"U4+60@X`0@L`&````$P#``"T
MFO__%@````!"#A!"@0).P4(.`%````!H`P``KIK__[P`````0@Y`1HD&D@B!
M`FB(!$;(6,%"R4+20@X`1`Y`@0*(!(D&D@A$DPH"/LA"TT+!0LE"TDH.`$0.
M0($"B0:2"$2(!),*`)````"\`P``%IO__ZH$````3@Z``UZ2"),*E`R!`H@$
M`FR)!I4.`RP!"L%"R$+50M)"TT+41,E"#@!""P):EA!,UF#)U5;(0L%"TD+3
M0M1"#@!$#H`#@0*(!(D&D@B3"I0,E0Z6$$R7$D;60M="EA"7$@,B`0K60M="
M"P/:`-;71)80EQ)$R=76UTB)!I4.EA"7$@`T````4`0``"R?___(`0```$(.
M0$*(!%*2"),*@0*)!I0,`T0!"L%"R$+)0M)"TT+40@X`0@L``$0```"(!```
MO*#__Z0`````0@XP1H@$B0:!`@)""L%"R$+)0@X`0@M$D@AL"M)""TS(0M)"
MP43)0@X`1`XP@0*(!(D&0I((`#````#0!```M(G__X@!````0@Y@3($"B0:(
M!)((DPH##`$*P4+(0LE"TT320@X`0@L````P````!`4``.2@__^@%````$0.
MP`5@@0*(!(D&D@B3"@-B%`K!1,A$R4321--$#@!""P``'````#@%``!0M?__
M5@````!"#A!&@0("2L%"#@````!@````6`4``(:U__\R`0```$(.4%2)!I0,
ME0Z!`H@$D@B3"FZ6$%"7$G+78-9"P4+(0LE"TD+30M1"U4(.`$(.4($"B`2)
M!I((DPJ4#)4.EA"7$DS73-8"2`J6$$@+4)80EQ(`/````+P%``!4MO__M`$`
M``!"#D!0B`2)!I,*E`R6$($"D@B5#@-0`0K(0L%"R4+20M-"U$+50M9"#@!$
M"P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````$`````````\`(````````!`````````/L"````````'0``
M``````!:!`````````P````````````````````-````````````````````
M&0````````"XJP```````!L`````````"``````````:`````````,"K````
M````'``````````(`````````/7^_V\`````L`(````````%`````````#@-
M````````!@````````"0`P````````H`````````>`0````````+````````
M`!@`````````%0````````````````````,`````````J*T````````"````
M`````$`%````````%``````````'`````````!<`````````"!0````````'
M`````````+`1````````"`````````"8!P````````D`````````&```````
M```>``````````@`````````^___;P`````!```(`````/G__V\`````"@``
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````/______
M____``````````!0&0```````%`9````````4!D```````!0&0```````%`9
M````````4!D```````!0&0```````%`9````````4!D```````!0&0``````
M`%`9````````4!D```````!0&0```````%`9````````4!D```````!0&0``
M`````%`9````````4!D```````!0&0```````%`9````````4!D```````!0
M&0```````%`9````````4!D```````!0&0```````%`9````````4!D`````
M``!0&0```````%`9````````4!D```````!0&0```````%`9````````4!D`
M``````!0&0```````%`9````````4!D```````!0&0```````%`9````````
M4!D```````!0&0```````%`9````````4!D```````!0&0```````%`9````
M````4!D```````!0&0```````%`9````````4!D```````!0&0```````%`9
M````````4!D```````!0&0```````%`9````````4!D```````!0&0``````
M`%`9````````R*L`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"E!!4BYP;0H`````````````````````````
M````````````````````````````````````````````````````````````
M1T-#.B`H06QP:6YE(#$T+C,N,"D@,30N,RXP`$%E````<FES8W8``5L````$
M$`5R=C8T:3)P,5]M,G`P7V$R<#%?9C)P,E]D,G`R7V,R<#!?>FEC<W(R<#!?
M>FEF96YC96DR<#!?>FUM=6PQ<#!?>F%A;6\Q<#!?>F%L<G-C,7`P```N<VAS
M=')T86(`+FYO=&4N9VYU+F)U:6QD+6ED`"YI;G1E<G``+F=N=2YH87-H`"YD
M>6YS>6T`+F1Y;G-T<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YT97AT`"YR;V1A
M=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?
M87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"YR:7-C
M=BYA='1R:6)U=&5S````````````````````````````````````````````
M```````````````````````````````````````````+````!P````(`````
M````<`(```````!P`@```````"0````````````````````$````````````
M````````'@````$````"`````````)0"````````E`(````````:````````
M`````````````0```````````````````"8```#V__]O`@````````"P`@``
M`````+`"````````X``````````$``````````@````````````````````P
M````"P````(`````````D`,```````"0`P```````*@)````````!0````(`
M```(`````````!@`````````.`````,````"`````````#@-````````.`T`
M``````!X!````````````````````0```````````````````$`````$````
M`@````````"P$0```````+`1````````6`(````````$``````````@`````
M````&`````````!*````!````$(`````````"!0````````(%````````$`%
M````````!````!`````(`````````!@`````````3P````$````&````````
M`%`9````````4!D```````"@`P``````````````````$``````````0````
M`````%0````!````!@````````#P'````````/`<````````0"\`````````
M``````````(```````````````````!:`````0````(`````````,$P`````
M```P3````````&!!```````````````````(````````````````````8@``
M``$````"`````````)"-````````D(T```````#4````````````````````
M!````````````````````'`````!`````@````````!HC@```````&B.````
M````_`4```````````````````@```````````````````!Z````#@````,`
M````````N*L```````"XFP````````@````````````````````(````````
M``@`````````A@````\````#`````````,"K````````P)L````````(````
M````````````````"``````````(`````````)(````&`````P````````#(
MJP```````,B;````````X`$````````%``````````@`````````$```````
M``";`````0````,`````````J*T```````"HG0```````%@"````````````
M```````(``````````@`````````H`````$````#``````````"P````````
M`*````````!0````````````````````"````````````````````*8````(
M`````P````````!0L````````%"@````````6`````````````````````@`
M``````````````````"K`````0```#````````````````````!0H```````
M`!P````````````````````!``````````$`````````M`````,``'``````
M````````````````;*````````!F`````````````````````0``````````
M``````````$````#`````````````````````````-*@````````Q@``````
:``````````````$`````````````````````
